Package {HomeRangeR}


Title: Predict Vertebrate Home-Range Sizes Using Allometric Models
Version: 0.1.0
Description: Provides empirically strong allometric predictions of the home-range size of most vertebrate species. Based on inputs of mean body size, taxonomic class, and optional classifications of environment and trophic level or foraging mode, 'HomeRangeR' predicts home-range size using the most appropriate model for the species selected from a collection of empirically derived vertebrate home-range allometries.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (≥ 3.5)
RoxygenNote: 7.3.3
Imports: dplyr
NeedsCompilation: no
Packaged: 2026-06-27 12:26:21 UTC; dalemoskoff
Author: Dale Moskoff [aut, cre]
Maintainer: Dale Moskoff <d.moskoff@mail.utoronto.ca>
Repository: CRAN
Date/Publication: 2026-07-03 12:00:21 UTC

HomeRangeR home-range allometry database

Description

Allometric scaling relationships used by HomeRangeR to estimate vertebrate home-range size (Moskoff & Mandrak, 2026).

Format

A data frame with 17 variables:

taxonomy

Taxonomic grouping

environment

Environmental grouping

trophic_level

Trophic guild or foraging mode

slope

Allometric slope (b)

slope_low

Lower 95 percent CI

slope_high

Upper 95 percent CI

intercept

Intercept (log10(a))

intercept_low

Lower 95 percent CI

intercept_high

Upper 95 percent CI

r2_multiple

Multiple R-squared

r2_adjusted

Adjusted R-squared

p_value

Model p-value

lambda

Phylogenetic signal

lambda_low

Lower 95 percent CI

lambda_high

Upper 95 percent CI

n

Sample size

response_unit

Units of home range

Moskoff, D. R., & Mandrak, N. E. (2026). A database of vertebrate home-range allometries for conservation applications. Unpublished manuscript. Department of Physical and Environmental Sciences, University of Toronto Scarborough.


List supported environment inputs

Description

List supported environment inputs

Usage

environment_options()

Value

Character vector of supported environment type classifications.


Predict mean home-range size of vertebrate species

Description

Predicts mean home-range size of bird, mammal, fish, lizard, snake, and turtle species using allometric scaling relationships derived from empirical data (Moskoff & Mandrak, 2026). HomeRangeR contains a hierarchy of allometric models fitted within nested subsets of taxonomic class, environment type, and trophic guild or foraging mode. The function automatically selects the most appropriate model available for the supplied combination of taxonomy, environment, and trophic level or foraging mode. When a finer-scale subset is unavailable or was not retained because it did not explain significant variation in home-range scaling, the function falls back to the most appropriate coarser grouping and returns a note describing the decision. See Moskoff & Mandrak (2026) for methods.

Usage

predict_home_range(
  body_mass_kg,
  taxonomy,
  environment = NA,
  trophic_level = NA
)

Arguments

body_mass_kg

Numeric. Mean body mass of the species in kilograms. Sex-weighted average preferred when species exhibits sexual size dimorphism.

taxonomy

Character string specifying the taxonomic class of the species. Supported values include:

  • "birds"

  • "mammals"

  • "fishes"

  • "lizards"

  • "snakes"

  • "turtles"

Amphibians are not currently represented in HomeRangeR.

environment

Optional character string specifying the environment occupied by the species. Supported values vary among taxonomic groups and include:

  • "terrestrial"

  • "marine"

  • "aerial"

  • "river"

  • "lake"

  • "freshwater"

  • "aquatic"

trophic_level

Optional trophic level or foraging mode classification.

Snakes and turtles are classified by foraging strategy as:

  • "active"

  • "ambush"

  • "mixed"

All other taxa are classified by trophic guild as:

  • "herbivorous"

  • "omnivorous"

  • "carnivorous"

Details

Allometric formulae used by HomeRangeR were obtained using phylogenetic generalized least square (PGLS) regressions of species' mean home-range size by mean body size. PGLS regression is an extension of standard least squares estimation including a phylogenetic covariance matrix representing the expected covariance structure among the residuals of the regression model based on phylogeny (Freckleton et al., 2002). PGLS was chosen over other regression methods to account for phylogenetic nonindependence of data points (Garland & Adolph, 1994; Harvey & Pagel, 1991; Perry & Pianka, 1997; Rees, 1995). Formulae used by HomeRangeR follow the syntax:

\log_{10}(HRA) = \log_{10}(a) + b \times \log_{10}(M)

where:

Predicted home-range size is returned on the original scale:

HRA = 10^{(\log_{10}(a) + b \log_{10}(M))}

Home-range estimates are reported in square kilometres (km^2) except for river fishes, for which home-range length is reported in linear kilometres (km). It is recommended that the home ranges of river fishes be converted from length to area using the mean width of the relevant occupied river estimated by the Stahler stream order, as per Cheng (2013).

The function returns both the estimated home-range area of the species and the metadata associated with the selected model, including confidence intervals, model fit statistics, phylogenetic signal estimates, size of species sample used to derive the home-range scaling relationship, and explanatory notes.

Value

A list containing:

References

Cheng, J. (2013). Spatial criteria used in IUCN assessment overestimate area of occupancy for freshwater taxa. Unpublished Master’s thesis. University of Toronto.

Freckleton, R.P., Harvey, P.H., & Pagel, M. (2002). Phylogenetic analysis and comparative data: A test and review of evidence. The American Naturalist, 160(6), 712–726. https://doi.org/10.1086/343873

Garland, T., & Adolph, S.C. (1994). Why not to do two-species comparative studies: Limitations on inferring adaptation. Physiological Zoology, 67, 797-828.

Harvey, P.H., & Pagel, M.D. (1991). The comparative method in evolutionary biology. Oxford University Press.

Moskoff, D.R., & Mandrak, N.E. (2026). A database of vertebrate home-range allometries for conservation applications. Unpublished manuscript. Department of Physical and Environmental Sciences, University of Toronto Scarborough.

Perry, G., & Pianka, E.R. (1997). Animal foraging: Past, present, and future. Trends in Ecology and Evolution, 12, 360-364.

Rees, M. (1995). EC-PC comparative analyses? Journal of Ecology, 83(5), 891-893. https://doi.org/10.2307/2261426

See Also

taxonomy_options, environment_options, trophic_level_options

Examples

# Marine mammal
predict_home_range(
  body_mass_kg = 10,
  taxonomy = "mammals",
  environment = "marine"
)

# Herbivorous terrestrial mammal
predict_home_range(
  body_mass_kg = 50,
  taxonomy = "mammals",
  environment = "terrestrial",
  trophic_level = "herbivorous"
)

# Herbivorous terrestrial fish
predict_home_range(
  body_mass_kg = 2,
  taxonomy = "fishes",
  environment = "marine",
  trophic_level = "herbivorous"
)

# Freshwater fish
predict_home_range(
  body_mass_kg = 1,
  taxonomy = "fishes",
  environment = "river"
)

# Display supported inputs
taxonomy_options()
environment_options()
trophic_level_options()


List supported taxonomy inputs

Description

List supported taxonomy inputs

Usage

taxonomy_options()

Value

Character vector of supported taxonomic groups.


List supported trophic guild / foraging strategy inputs

Description

List supported trophic guild / foraging strategy inputs

Usage

trophic_level_options()

Value

Character vector of supported trophic guild or foraging mode classifications.